@@ -371,7 +371,7 @@ def selectplots(plotsDF):
     if __name__ == '__main__' :
         RandomTable = pd.read_pickle('RandomTable.pkl')
     else:
-        RandomTable = pd.read_pickle(os.path.dirname(os.path.realpath(__file__))+'\RandomTable.pkl')
+        RandomTable = pd.read_pickle(os.path.dirname(os.path.realpath(__file__))+('\\' if os.name=='nt' else '/')+'RandomTable.pkl')
     if int(stmgrp) <=104 :
         for num in RandomTable[int(stmgrp)]:
             if int(num) <= tplot:
@@ -507,7 +507,8 @@ def agriplotcmd():
     Usgstr='''
 Usage : Generates Excel file from Plot Data file
 
-        agriplotcmd   FILENAME
+        agriplotcmd   FILENAME including its FullPath if the file is not in the current directory
+        e.g.  agriplotcmd   plots.xlsx
         
         Optional : Use option 'checkfile' To Compare with a File
         e.g.  agriplotcmd   FILENAME   --checkfile  FILENAMEToCompare
@@ -525,6 +526,7 @@ def selectplotscmd():
 Usage : Takes 'Total Number of Plots/Last SNo.' and Gives the Selected Plots
 
         selectplotscmd  Number-of-Plots/Last-SNo.
+        e.g.  selectplotscmd  9788
 
         '''
     argDict=getArg(usagestr=Usgstr, customarg='checkfile')
@@ -541,20 +543,26 @@ def getsubplotscmd():
 Usage : Pass the Subplots of a Plot separated by comma in any order to get All the Possible Subplots in Sequence
 
         getsubplotscmd   Comma-Separated-SubPlots
+        e.g.  getsubplotscmd  6A,6,2C3B,10,7A1,4D5C3B1
         '''
     argDict=getArg(usagestr=Usgstr, customarg='checkfile')
     if argDict:
         subplots=argDict['main'].replace('[','').replace(']','')
         splots=getsubplots(subplots)
-        print('\n   SubPlots:: \n\n        '+'\n        '.join([ i  for i in splots ])+'\n\n')
+        ppt=''; splot=[]
+        for splt in splots:
+            if getNumber(splt) != ppt:
+                ppt=getNumber(splt)
+                splt='\n        '+splt
+            splot.append(splt)
+        print('\n   SubPlots:: \n\n        '+'\n      '.join([ '- '+i  if  i in subplots.split(',') else '  '+i for i in splot ])+'\n\n') 
 
 
 
 if __name__ == '__main__' :
 
-    FILE_NAME='tplots.xlsx'
+    FILE_NAME='plots.xlsx'
     #FILE_NAME='plotdata'
-    #FILE_NAME='plot1.xlsx'
     #agriplot(FILE_NAME, checkfile='done' )
     agriplot(FILE_NAME )
     
